.. pyhf documentation master file, created by
   sphinx-quickstart on Fri Feb  9 11:58:49 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. toctree::
   :hidden:

   intro
   likelihood
   learn
   examples
   talks
   installation
   development
   faq
   babel
   cli
   api
   citations
   governance/ROADMAP

.. raw:: html

   <a class="github-fork-ribbon right-top fixed" href="https://github.com/scikit-hep/pyhf/fork" data-ribbon="Fork me on GitHub" title="Fork me on GitHub">Fork me on GitHub</a>

.. mdinclude:: ../README.md

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
